@@ -15,15 +15,15 @@ available in a local directory, it is loaded directly into memory.
 https://registry.opendata.aws/noaa-goes/
 """
 
-from os import pardir
-from pathlib import Path
-from datetime import datetime, timedelta
 import multiprocessing
+from concurrent.futures import ThreadPoolExecutor, as_completed, wait
+from datetime import datetime, timedelta
+from pathlib import Path
 
+import numpy as np
+import pandas as pd
 import s3fs
 import xarray as xr
-import pandas as pd
-import numpy as np
 
 # NOTE: These config dict values are retrieved from __init__ and read
 # from the file ${HOME}/.config/goes2go/config.toml
@@ -37,6 +37,7 @@ fs = s3fs.S3FileSystem(anon=True)
 _satellite = {
     "noaa-goes16": [16, "16", "G16", "EAST", "GOES16"],
     "noaa-goes17": [17, "17", "G17", "WEST", "GOES17"],
+    "noaa-goes18": [18, "18", "G18", "WEST", "GOES18"],
 }
 
 _domain = {
@@ -46,7 +47,7 @@ _domain = {
 }
 
 _product = {
-    # Assume goes17 has same products as goes16
+    # Assume goes17 and goes18 have same products as goes16
     i.split("/")[-1]: []
     for i in fs.ls(f"noaa-goes16")
 }
@@ -110,17 +111,10 @@ def _check_param_inputs(**params):
         product in _product
     ), f"product must be one of {list(_product .keys())} or an alias {list(_product .values())}"
 
-    if verbose:
-        print(f" _______________________________")
-        print(f" | Satellite: {satellite:<17s}|")
-        print(f" |   Product: {product:<17s}|")
-        if domain != None:
-            print(f" |    Domain: {domain:<17s}|")
-
     return satellite, product, domain
 
 
-def _goes_file_df(satellite, product, start, end, refresh=True):
+def _goes_file_df(satellite, product, start, end, bands=None, refresh=True):
     """
     Get list of requested GOES files as pandas.DataFrame.
 
@@ -130,12 +124,17 @@ def _goes_file_df(satellite, product, start, end, refresh=True):
     product : str
     start : datetime
     end : datetime
+    band : None, int, or list
+        Specify the ABI channels to retrieve.
     refresh : bool
         Refresh the s3fs.S3FileSystem object when files are listed.
         Default True will refresh and not use a cached list.
     """
     params = locals()
 
+    start = pd.to_datetime(start)
+    end = pd.to_datetime(end)
+
     DATES = pd.date_range(f"{start:%Y-%m-%d %H:00}", f"{end:%Y-%m-%d %H:00}", freq="1H")
 
     # List all files for each date
@@ -147,10 +146,30 @@ def _goes_file_df(satellite, product, start, end, refresh=True):
     # Build a table of the files
     # --------------------------
     df = pd.DataFrame(files, columns=["file"])
-    df[["start", "end", "creation"]] = (
-        df["file"].str.rsplit("_", expand=True, n=3).loc[:, 1:]
+    df[["product_mode", "satellite", "start", "end", "creation"]] = (
+        df["file"].str.rsplit("_", expand=True, n=5).loc[:, 1:]
     )
 
+    # Todo: this could use some clean up !
+    if product.startswith("ABI"):
+        product_mode = df.product_mode.str.rsplit("-", 1, expand=True)
+        df["product"] = product_mode[0]
+        df["mode_bands"] = product_mode[1]
+
+        mode_bands = df.mode_bands.str.split("C", expand=True)
+        df["mode"] = mode_bands[0].str[1:].astype(int)
+        try:
+            df["band"] = mode_bands[1].astype(int)
+        except:
+            # No channel data
+            df["band"] = None
+
+        # Filter files by band number
+        if bands is not None:
+            if not hasattr(bands, "__len__"):
+                bands = [bands]
+            df = df.loc[df.band.isin(bands)]
+
     # Filter files by requested time range
     # ------------------------------------
     # Convert filename datetime string to datetime object
@@ -167,104 +186,34 @@ def _goes_file_df(satellite, product, start, end, refresh=True):
     return df
 
 
-def _download_MP(src, save_dir, overwrite, i=1, n=1, verbose=True):
-    """
-    Download a single file -- a multiprocessing helper
+def _download(df, save_dir, overwrite, max_threads=10, verbose=False):
+    """Download the files from a DataFrame listing with multithreading"""
 
-    Parameters
-    ----------
-    src : str
-        The source path of the file (path relative to S3 or ``save_dir``)
-    save_dir : str or pathlib.Path
-        Directory to save the file when it is downloaded.
-    overwrite : bool
-        True - overwrite files if the exist
-        False - skip download if the file exists (default)
-    i, n : int
-        The iteration number and total number of files (primarily for
-        the multiprocessor counter).
-    """
+    def do_download(src):
+        dst = Path(save_dir) / src
+        if not dst.parent.is_dir():
+            dst.parent.mkdir(parents=True, exist_ok=True)
+        if dst.is_file() and not overwrite:
+            if verbose:
+                print(f" 👮🏻‍♂️ File already exists. Do not overwrite: {dst}")
+        else:
+            # Downloading file from AWS
+            fs.get(src, str(dst))
 
-    # File destination
-    dst = Path(save_dir) / src
+    ################
+    # Multithreading
+    tasks = len(df)
+    threads = min(tasks, max_threads)
 
-    if not dst.parent.is_dir():
-        dst.parent.mkdir(parents=True, exist_ok=True)
-        print(f"👨🏻‍🏭 Created directory: [{dst.parent}]", end="")
+    with ThreadPoolExecutor(threads) as exe:
+        futures = [exe.submit(do_download, src) for src in df.file]
 
-    if verbose:
-        print(
-            f"\r🏇🏻💨 Downloading ({i:,}/{n:,}) file from AWS to Local Disk. {src} > {dst}",
-            end=" ",
-        )
+        # nothing is returned in the list
+        this_list = [future.result() for future in as_completed(futures)]
 
-    if dst.is_file() and not overwrite:
-        if verbose:
-            print("---- 👮🏻‍♂️ File already exists. Do not overwrite.", end="")
-    else:
-        # Downloading file from AWS
-        # NOTE: The destination is `str(dst)` and not just `dst` because
-        #       Gaffney does not like a Path object for some reason.
-        fs.get(src, str(dst))
-
-
-def _download(df, **params):
-    """
-    Download each file in the pandas.DataFrame to ``save_dir``.
-
-    Use multiprocessing to improve download time.
-
-    Parameters
-    ----------
-    df : pandas.DataFrame
-        A DataFrame created by ``_goes_file_df`` with a list of files
-        to download from the GOES s3 bucket.
-    save_dir : str or pathlib.Path
-        Directory the files will be downloaded to.
-        The default location (set as a variable in this script)
-        is ``~/data/``.
-    max_cpus : int or None
-        If None, use all available CPUs. Else, specify the number of
-        CPUs to use.
-    overwrite : bool
-        True - overwrite files if the exist
-        False - skip download if the file exists (default)
-    """
-    params.setdefault("max_cpus", None)
-    params.setdefault("verbose", True)
-    save_dir = params["save_dir"]
-    overwrite = params["overwrite"]
-    max_cpus = params["max_cpus"]
-    verbose = params["verbose"]
-
-    n = len(df.file)
-    if n == 0:
-        print("🛸 No data to download.")
-    elif n == 1:
-        # If we only have one file, we don't need multiprocessing
-        _download_MP(df.file[0], save_dir, overwrite, 1, 1, verbose)
-    elif max_cpus == 1:
-        [_download_MP(df.file[i], save_dir, overwrite, i, n, verbose) for i in range(n)]
-    else:
-        # Use Multiprocessing to download multiple files.
-        if max_cpus is None:
-            max_cpus = multiprocessing.cpu_count()
-        cpus = np.minimum(multiprocessing.cpu_count(), max_cpus)
-        cpus = np.minimum(cpus, n)
-
-        inputs = [
-            (src, save_dir, overwrite, i, n, verbose)
-            for i, src in enumerate(df.file, start=1)
-        ]
-
-        with multiprocessing.Pool(cpus) as p:
-            results = p.starmap(_download_MP, inputs)
-            p.close()
-            p.join()
-    if verbose:
-        print(
-            f"\r{'':1000}\r📦 Finished downloading [{n}] files to [{save_dir/Path(df.file[0]).parents[3]}]."
-        )
+    print(
+        f"📦 Finished downloading [{len(df)}] files to [{save_dir/Path(df.file[0]).parents[3]}]."
+    )
 
 
 def _as_xarray_MP(src, save_dir, i=None, n=None, verbose=True):
@@ -375,6 +324,7 @@ def goes_timerange(
     overwrite=config["timerange"].get("overwrite"),
     save_dir=config["timerange"].get("save_dir"),
     max_cpus=config["timerange"].get("max_cpus"),
+    bands=None,
     s3_refresh=config["timerange"].get("s3_refresh"),
     verbose=config["timerange"].get("verbose", True),
 ):
@@ -388,12 +338,13 @@ def goes_timerange(
     recent : timedelta or pandas-parsable timedelta str
         Required if start and end are None. If timedelta(hours=1), will
         get the most recent files for the past hour.
-    satellite : {'goes16', 'goes17'}
+    satellite : {'goes16', 'goes17', 'goes18'}
         Specify which GOES satellite.
         The following alias may also be used:
 
         - ``'goes16'``: 16, 'G16', or 'EAST'
         - ``'goes17'``: 17, 'G17', or 'WEST'
+        - ``'goes18'``: 18, 'G18', or 'WEST'
 
     product : {'ABI', 'GLM', other GOES product}
         Specify the product name.
@@ -423,6 +374,8 @@ def goes_timerange(
         - True: Download the file even if it exists.
         - False Do not download the file if it already exists
     max_cpus : int
+    bands : None, int, or list
+        ONLY FOR L1b-Rad products; specify the bands you want
     s3_refresh : bool
         Refresh the s3fs.S3FileSystem object when files are listed.
 
@@ -461,10 +414,10 @@ def goes_timerange(
         start = datetime.utcnow() - recent
         end = datetime.utcnow()
 
-    df = _goes_file_df(satellite, product, start, end, refresh=s3_refresh)
+    df = _goes_file_df(satellite, product, start, end, bands=bands, refresh=s3_refresh)
 
     if download:
-        _download(df, **params)
+        _download(df, save_dir=save_dir, overwrite=overwrite, verbose=verbose)
 
     if return_as == "filelist":
         df.attrs["filePath"] = save_dir
@@ -482,6 +435,7 @@ def goes_latest(
     download=config["latest"].get("download"),
     overwrite=config["latest"].get("overwrite"),
     save_dir=config["latest"].get("save_dir"),
+    bands=None,
     s3_refresh=config["latest"].get("s3_refresh"),
     verbose=config["latest"].get("verbose", True),
 ):
@@ -490,12 +444,13 @@ def goes_latest(
 
     Parameters
     ----------
-    satellite : {'goes16', 'goes17'}
+    satellite : {'goes16', 'goes17', 'goes18'}
         Specify which GOES satellite.
         The following alias may also be used:
 
         - ``'goes16'``: 16, 'G16', or 'EAST'
         - ``'goes17'``: 17, 'G17', or 'WEST'
+        - ``'goes18'``: 18, 'G18', or 'WEST'
 
     product : {'ABI', 'GLM', other GOES product}
         Specify the product name.
@@ -524,6 +479,8 @@ def goes_latest(
     overwrite : bool
         - True: Download the file even if it exists.
         - False Do not download the file if it already exists
+    bands : None, int, or list
+        ONLY FOR L1b-Rad products; specify the bands you want
     s3_refresh : bool
         Refresh the s3fs.S3FileSystem object when files are listed.
     """
@@ -540,7 +497,7 @@ def goes_latest(
     start = datetime.utcnow() - timedelta(hours=1)
     end = datetime.utcnow()
 
-    df = _goes_file_df(satellite, product, start, end, refresh=s3_refresh)
+    df = _goes_file_df(satellite, product, start, end, bands=bands, refresh=s3_refresh)
 
     # Filter for specific mesoscale domain
     if domain is not None and domain.upper() in ["M1", "M2"]:
@@ -550,7 +507,7 @@ def goes_latest(
     df = df.loc[df.start == df.start.max()].reset_index(drop=True)
 
     if download:
-        _download(df, **params)
+        _download(df, save_dir=save_dir, overwrite=overwrite, verbose=verbose)
 
     if return_as == "filelist":
         df.attrs["filePath"] = save_dir
@@ -570,11 +527,12 @@ def goes_nearesttime(
     download=config["nearesttime"].get("download"),
     overwrite=config["nearesttime"].get("overwrite"),
     save_dir=config["nearesttime"].get("save_dir"),
+    bands=None,
     s3_refresh=config["nearesttime"].get("s3_refresh"),
     verbose=config["nearesttime"].get("verbose", True),
 ):
     """
-    Get the latest available GOES data.
+    Get the GOES data nearest a specified time.
 
     Parameters
     ----------
@@ -583,12 +541,13 @@ def goes_nearesttime(
         May also use a pandas-interpretable datetime string.
     within : timedelta or pandas-parsable timedelta str
         Timerange tht the nearest observation must be.
-    satellite : {'goes16', 'goes17'}
+    satellite : {'goes16', 'goes17', 'goes18'}
         Specify which GOES satellite.
         The following alias may also be used:
 
         - ``'goes16'``: 16, 'G16', or 'EAST'
         - ``'goes17'``: 17, 'G17', or 'WEST'
+        - ``'goes18'``: 18, 'G18', or 'WEST'
 
     product : {'ABI', 'GLM', other GOES product}
         Specify the product name.
@@ -617,6 +576,8 @@ def goes_nearesttime(
     overwrite : bool
         - True: Download the file even if it exists.
         - False: Do not download the file if it already exists
+    bands : None, int, or list
+        ONLY FOR L1b-Rad products; specify the bands you want
     s3_refresh : bool
         Refresh the s3fs.S3FileSystem object when files are listed.
     """
@@ -637,7 +598,7 @@ def goes_nearesttime(
     start = attime - within
     end = attime + within
 
-    df = _goes_file_df(satellite, product, start, end, refresh=s3_refresh)
+    df = _goes_file_df(satellite, product, start, end, bands=bands, refresh=s3_refresh)
 
     # return df, start, end, attime
 
@@ -648,8 +609,10 @@ def goes_nearesttime(
     # Get row that matches the nearest time
     df = df.sort_values("start")
     df = df.set_index(df.start)
-    nearest_time_index = df.index.get_loc(attime, method="nearest")
-    df = df.iloc[[nearest_time_index]]
+    unique_times_index = df.index.unique()
+    nearest_time_index = unique_times_index.get_indexer([attime], method='nearest')
+    nearest_time = unique_times_index[nearest_time_index]
+    df = df.loc[nearest_time]
     df = df.reset_index(drop=True)
 
     n = len(df.file)
@@ -658,7 +621,7 @@ def goes_nearesttime(
         return None
 
     if download:
-        _download(df, **params)
+        _download(df, save_dir=save_dir, overwrite=overwrite, verbose=verbose)
 
     if return_as == "filelist":
         df.attrs["filePath"] = save_dir
